@@ -38,7 +38,7 @@ import pytz
 
 import intelmq.lib.utils as utils
 
-from typing import Optional
+from typing import Optional, Union
 
 __all__ = ['Base64', 'Boolean', 'ClassificationType', 'DateTime', 'FQDN',
            'Float', 'Accuracy', 'GenericType', 'IPAddress', 'IPNetwork',
@@ -316,31 +316,40 @@ class DateTime(String):
     @staticmethod
     def __parse(value: str) -> Optional[str]:
         try:
-            return utils.decode(DateTime.parse_utc_isoformat(value))
+            DateTime.parse_utc_isoformat(value)
         except ValueError:
             pass
+        else:
+            return utils.decode(value)
 
         try:
             value = dateutil.parser.parse(value, fuzzy=True)
             value = value.astimezone(pytz.utc)
             value = value.isoformat()
-        except ValueError:
+        except (ValueError, OverflowError):
             return None
         return utils.decode(value)
 
     @staticmethod
-    def parse_utc_isoformat(value: str) -> Optional[datetime.datetime]:
+    def parse_utc_isoformat(value: str, return_datetime: bool = False) -> Union[datetime.datetime, str]:
         """
         Parse format generated by datetime.isoformat() method with UTC timezone.
         It is much faster than universal dateutil parser.
+        Can be used for parsing DateTime fields which are already parsed.
+
+        Returns a string with ISO format.
+        If return_datetime is True, the return value is a datetime.datetime object.
         """
         try:
-            datetime.datetime.strptime(value, '%Y-%m-%dT%H:%M:%S+00:00')
+            dtvalue = datetime.datetime.strptime(value, '%Y-%m-%dT%H:%M:%S+00:00')
         except ValueError:
             # With microseconds
-            datetime.datetime.strptime(value, '%Y-%m-%dT%H:%M:%S.%f+00:00')
+            dtvalue = datetime.datetime.strptime(value, '%Y-%m-%dT%H:%M:%S.%f+00:00')
 
-        return value
+        if return_datetime:
+            return pytz.utc.localize(dtvalue)
+        else:
+            return value
 
     @staticmethod
     def from_epoch_millis(tstamp: str, tzone='UTC') -> datetime.datetime:
@@ -358,7 +367,7 @@ class DateTime(String):
             return DateTime.from_timestamp(int_tstamp // 1000, tzone)
 
     @staticmethod
-    def from_timestamp(tstamp: str, tzone='UTC') -> str:
+    def from_timestamp(tstamp: int, tzone='UTC') -> str:
         """
         Returns ISO formatted datetime from given timestamp.
         You can give timezone for given timestamp, UTC by default.
@@ -425,10 +434,14 @@ class DateTime(String):
     def convert_fuzzy(value) -> str:
         value = dateutil.parser.parse(value, fuzzy=True)
         if not value.tzinfo and sys.version_info <= (3, 6):
-            value = pytz.utc.localize(value)
+            value = pytz.utc.localize(value)  # pragma: no cover
         elif not value.tzinfo:
             value.astimezone(pytz.utc)
-        return value.isoformat()
+        iso = value.isoformat()
+        if '+' not in iso:
+            return iso + '+00:00'
+        else:
+            return iso
 
     @staticmethod
     def convert(value, format='fuzzy') -> str:
@@ -459,7 +472,7 @@ DateTime.TIME_CONVERSIONS = {'timestamp': DateTime.from_timestamp,
                              'epoch_millis': DateTime.from_epoch_millis,
                              'from_format': DateTime.convert_from_format,
                              'from_format_midnight': DateTime.convert_from_format_midnight,
-                             'utc_isoformat': 'parse_utc_isoformat',
+                             'utc_isoformat': DateTime.parse_utc_isoformat,
                              'fuzzy': DateTime.convert_fuzzy,
                              None: DateTime.convert_fuzzy,
                              }
@@ -661,7 +674,7 @@ class IPAddress(String):
     """
     Type for IP addresses, all families. Uses the ipaddress module.
 
-    Sanitation accepts strings and objects of ipaddress.IPv4Address and ipaddress.IPv6Address.
+    Sanitation accepts integers, strings and objects of ipaddress.IPv4Address and ipaddress.IPv6Address.
 
     Valid values are only strings. 0.0.0.0 is explicitly not allowed.
     """
@@ -690,12 +703,28 @@ class IPAddress(String):
         return True
 
     @staticmethod
-    def sanitize(value: str) -> Optional[str]:
+    def sanitize(value: Union[int, str]) -> Optional[str]:
+        if not isinstance(value, int):  # can be str/bytes or ipaddress.ip_address object
+            try:
+                value = GenericType().sanitize(value)
+            except ValueError:
+                return None
 
+        # support for integer IP-address which are given as string
         try:
-            value = GenericType().sanitize(value)
-        except ValueError:
-            return None
+            if (str(value) == str(int(value))):
+                value = int(value)
+        except (ValueError, TypeError):
+            pass
+        # Convert integers to strings
+        # either from the conversion above, or the value is already given as int
+        if isinstance(value, int):
+            try:
+                value = ipaddress.ip_address(value)
+            except ValueError:
+                return None
+            # we don't need the specialized checks below, return early
+            return GenericType().sanitize(value)
 
         try:
             # Remove the scope ID if it's detected.
