@@ -27,6 +27,7 @@ import shutil
 import sys
 import tarfile
 import traceback
+import warnings
 import zipfile
 from typing import Any, Dict, Generator, Iterator, Optional, Sequence, Union
 
@@ -36,6 +37,7 @@ from termstyle import red
 
 import intelmq
 from intelmq.lib.exceptions import DecodingError
+from intelmq import DEFAULTS_CONF_FILE
 
 __all__ = ['base64_decode', 'base64_encode', 'decode', 'encode',
            'load_configuration', 'load_parameters', 'log', 'parse_logline',
@@ -205,7 +207,7 @@ def load_configuration(configuration_filepath: str) -> dict:
 
 def write_configuration(configuration_filepath: str,
                         content: dict, backup: bool = True,
-                        new=False) -> bool:
+                        new=False) -> Optional[bool]:
     """
     Writes a configuration to the file, optionally with making a backup.
     Checks if the file needs to be written at all.
@@ -254,7 +256,7 @@ def load_parameters(*configs: dict) -> Parameters:
     return parameters
 
 
-class FileHandler(logging.FileHandler):
+class RotatingFileHandler(logging.handlers.RotatingFileHandler):
     shell_color_pattern = re.compile(r'\x1b\[\d+m')
 
     def emit_print(self, record):
@@ -301,10 +303,12 @@ class ListHandler(logging.StreamHandler):
         self.buffer.append((record.levelname.lower(), record.getMessage()))
 
 
-def log(name: str, log_path: Union[str, bool] = intelmq.DEFAULT_LOGGING_PATH, log_level: str = intelmq.DEFAULT_LOGGING_LEVEL,
+def log(name: str, log_path: Union[str, bool] = intelmq.DEFAULT_LOGGING_PATH,
+        log_level: str = intelmq.DEFAULT_LOGGING_LEVEL,
         stream: Optional[object] = None, syslog: Union[bool, str, list, tuple] = None,
         log_format_stream: str = LOG_FORMAT_STREAM,
-        logging_level_stream: Optional[str] = None):
+        logging_level_stream: Optional[str] = None,
+        log_max_size: Optional[int] = 0, log_max_copies: Optional[int] = None):
     """
     Returns a logger instance logging to file and sys.stderr or other stream.
     The warnings module will log to the same handlers.
@@ -326,6 +330,10 @@ def log(name: str, log_path: Union[str, bool] = intelmq.DEFAULT_LOGGING_PATH, lo
         logging_level_stream:
             The logging level for stream (console) output.
             By default the same as log_level.
+        log_max_size:
+            The maximum size of the logfile. 0 means no restriction.
+        log_max_copies:
+            Maximum number of logfiles to keep.
 
     Returns:
         logger: An instance of logging.Logger
@@ -347,7 +355,9 @@ def log(name: str, log_path: Union[str, bool] = intelmq.DEFAULT_LOGGING_PATH, lo
         logging_level_stream = log_level
 
     if log_path and not syslog:
-        handler = FileHandler("%s/%s.log" % (log_path, name))
+        handler = RotatingFileHandler("%s/%s.log" % (log_path, name),
+                                      maxBytes=log_max_size if log_max_size else 0,
+                                      backupCount=log_max_copies)
         handler.setLevel(log_level)
         handler.setFormatter(logging.Formatter(LOG_FORMAT))
     elif syslog:
@@ -492,6 +502,7 @@ def extract_tar(file):
 
     def extract(filename):
         return tar.extractfile(filename).read()
+
     return tuple(file.name for file in tar.getmembers()), tar, extract
 
 
@@ -557,9 +568,9 @@ def unzip(file: bytes, extract_files: Union[bool, list], logger=None,
 
     if files is None:
         if return_names:
-            return ((None, archive), )
+            return ((None, archive),)
         else:
-            return (archive, )
+            return (archive,)
 
     if logger:
         logger.debug("Found files %r in archive.", files)
@@ -608,7 +619,7 @@ def object_pair_hook_bots(*args, **kwargs) -> Dict:
 
     """
     # Do not sort collector bots
-    if len(args[0]) and len(args[0][0]) == 2 and isinstance(args[0][0][1], dict) and\
+    if len(args[0]) and len(args[0][0]) == 2 and isinstance(args[0][0][1], dict) and \
             'module' in args[0][0][1] and '.collectors' in args[0][0][1]['module']:
         return collections.OrderedDict(*args, **kwargs)
     # Do not sort bot groups
@@ -678,11 +689,11 @@ def version_smaller(version1: tuple, version2: tuple) -> Optional[bool]:
     if len(version1) == 3:
         version1 = version1 + ('stable', 0)
     if len(version1) == 4:
-        version1 = version1 + (0, )
+        version1 = version1 + (0,)
     if len(version2) == 3:
         version2 = version2 + ('stable', 0)
     if len(version2) == 4:
-        version2 = version2 + (0, )
+        version2 = version2 + (0,)
     for level1, level2 in zip(version1, version2):
         if level1 > level2:
             return False
@@ -693,7 +704,7 @@ def version_smaller(version1: tuple, version2: tuple) -> Optional[bool]:
 
 def lazy_int(value: Any) -> Optional[Any]:
     """
-    Tries to conver the value to int if possible. Original value otherwise
+    Tries to convert the value to int if possible. Original value otherwise
     """
     try:
         return int(value)
@@ -705,9 +716,10 @@ class TimeoutHTTPAdapter(requests.adapters.HTTPAdapter):
     """
     A requests-HTTP Adapter which can set the timeout generally.
     """
+
     def __init__(self, *args, timeout=None, **kwargs):
         self.timeout = timeout
-        return super().__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     def send(self, *args, **kwargs):
         kwargs['timeout'] = self.timeout
@@ -715,9 +727,18 @@ class TimeoutHTTPAdapter(requests.adapters.HTTPAdapter):
 
 
 def create_request_session_from_bot(bot: type) -> requests.Session:
+    warnings.warn("This function is deprecated in favor of create_request_session"
+                  " and will be removed in version 3.0.0.",
+                  DeprecationWarning)
+    return create_request_session(bot)
+
+
+def create_request_session(bot: type = None) -> requests.Session:
     """
     Creates a requests.Session object preconfigured with the parameters
     set by the Bot.set_request_parameters and given by the bot instance.
+    If no bot is specified then the Session is preconfigured only with
+    parameters from defaults.conf.
 
     Parameters:
         bot_instance: An instance of a Bot
@@ -725,16 +746,53 @@ def create_request_session_from_bot(bot: type) -> requests.Session:
     Returns:
         session: A preconfigured instance of requests.Session
     """
+    defaults = load_configuration(DEFAULTS_CONF_FILE)
     session = requests.Session()
-    session.headers.update(bot.http_header)
-    session.auth = bot.auth
-    session.proxies = bot.proxy
-    session.cert = bot.ssl_client_cert
-    session.verify = bot.http_verify_cert
-    adapter = TimeoutHTTPAdapter(max_retries=bot.http_timeout_max_tries - 1,
-                                 timeout=bot.http_timeout_sec)
+
+    # tls settings
+    if bot and hasattr(bot, 'http_verify_cert'):
+        session.verify = bot.http_verify_cert
+    else:
+        session.verify = defaults.get('http_verify_cert', True)
+
+    # tls certificate settings
+    if bot and hasattr(bot, 'ssl_client_cert'):
+        session.cert = bot.ssl_client_cert
+
+    # auth settings
+    if bot and hasattr(bot, 'auth'):
+        session.auth = bot.auth
+
+    # headers settings
+    if bot and hasattr(bot, 'http_header'):
+        session.headers.update(bot.http_header)
+    elif defaults.get('http_user_agent'):
+        session.headers.update({"User-Agent": defaults.get('http_user_agent')})
+
+    # proxy settings
+    if bot and hasattr(bot, 'proxy'):
+        session.proxies = bot.proxy
+    elif defaults.get('http_proxy') and defaults.get('https_proxy'):
+        session.proxies = {
+            'http': defaults.get('http_proxy'),
+            'https': defaults.get('https_proxy')
+        }
+
+    # timeout settings
+    if bot and hasattr(bot, 'http_timeout_max_tries'):
+        max_retries = bot.http_timeout_max_tries - 1
+    else:
+        max_retries = defaults.get('http_timeout_max_tries', 3)
+
+    if bot and hasattr(bot, 'http_timeout_sec'):
+        timeout = bot.http_timeout_sec
+    else:
+        timeout = defaults.get('http_timeout_sec', 30)
+
+    adapter = TimeoutHTTPAdapter(max_retries=max_retries, timeout=timeout)
     session.mount('http://', adapter)
     session.mount('https://', adapter)
+
     return session
 
 
