@@ -2,11 +2,14 @@
 """
 Testing harmonization classes
 """
+import datetime
 import ipaddress
+import time
 import unittest
 
 import intelmq.lib.harmonization as harmonization
 import intelmq.lib.test as test
+import pytz
 
 
 class TestHarmonization(unittest.TestCase):
@@ -17,7 +20,7 @@ class TestHarmonization(unittest.TestCase):
         self.assertTrue(harmonization.Boolean.is_valid(False))
 
     def test_boolean_valid_other(self):
-        """ Test Boolean.is_valid with otehr invalid values. """
+        """ Test Boolean.is_valid with other invalid values. """
         self.assertFalse(harmonization.Boolean.is_valid(None,))
         self.assertFalse(harmonization.Boolean.is_valid('True'))
         self.assertFalse(harmonization.Boolean.is_valid(0))
@@ -70,7 +73,7 @@ class TestHarmonization(unittest.TestCase):
         self.assertFalse(harmonization.Integer.is_valid('b13', sanitize=True))
 
     def test_float_valid_flaot(self):
-        """ Test Float.is_valid with flaot and integer values. """
+        """ Test Float.is_valid with float and integer values. """
         self.assertTrue(harmonization.Float.is_valid(-4532, sanitize=False))
         self.assertTrue(harmonization.Float.is_valid(1337, sanitize=False))
         self.assertTrue(harmonization.Float.is_valid(1337.2354,
@@ -113,7 +116,7 @@ class TestHarmonization(unittest.TestCase):
                                                          sanitize=False))
 
     def test_ipaddress_valid_invalid(self):
-        """ Test IPAddress.is_valid with invalid arguments. """
+        """ Test IPAddress.is_valid with invEqual arguments. """
         self.assertFalse(harmonization.IPAddress.is_valid('192.0.2.1/24',
                                                           sanitize=False))
         self.assertFalse(harmonization.IPAddress.is_valid('2001:DB8::/32',
@@ -125,7 +128,8 @@ class TestHarmonization(unittest.TestCase):
 
     def test_ipaddress_sanitize(self):
         """ Test IPAddress.is_valid and sanitize with valid arguments. """
-        self.assertTrue(harmonization.IPAddress.sanitize(' 192.0.2.1\r\n'))
+        self.assertEqual(harmonization.IPAddress.sanitize(' 192.0.2.1\r\n'),
+                         '192.0.2.1')
         self.assertTrue(harmonization.IPAddress.is_valid(' 192.0.2.1\r\n',
                                                          sanitize=True))
         self.assertTrue(harmonization.IPAddress.is_valid(b'2001:DB8::1',
@@ -134,9 +138,13 @@ class TestHarmonization(unittest.TestCase):
                                                          sanitize=True))
         self.assertTrue(harmonization.IPAddress.is_valid('fe80::1c41:b16d:ff5e:689d%bnep0',
                                                           sanitize=True))
+        self.assertEqual(harmonization.IPAddress.sanitize('2130706433'),
+                         '127.0.0.1')
+        self.assertEqual(harmonization.IPAddress.sanitize(2130706433),
+                         '127.0.0.1')
 
     def test_ipaddress_sanitize_invalid(self):
-        """ Test IPAddress.is_valid ans sanitize with invalid arguments. """
+        """ Test IPAddress.is_valid and sanitize with invalid arguments. """
         self.assertFalse(harmonization.IPAddress.is_valid(' 192.0.2.0/24\r\n',
                                                           sanitize=True))
         self.assertFalse(harmonization.IPAddress.is_valid(b'2001:DB8::1/32',
@@ -189,6 +197,8 @@ class TestHarmonization(unittest.TestCase):
         self.assertFalse(harmonization.DateTime.is_valid(
             '2015-08-31T36:16:10+00:00'
         ))
+        # This is a telephone number. dateutil.parser.parse will throw OverflowError here
+        self.assertFalse(harmonization.DateTime.is_valid('0018005550199'))
 
     def test_datetime_from_epoch_millis(self):
         """ Test DateTime.from_epoch_millis method. """
@@ -235,6 +245,7 @@ class TestHarmonization(unittest.TestCase):
         with self.assertRaises(TypeError):
             harmonization.DateTime.from_timestamp('1441008970')
 
+    @unittest.skipIf(time.timezone != 0, 'Test only works with UTC')
     def test_datetime_convert(self):
         self.assertEqual('2019-07-01T15:15:15+00:00',
                          harmonization.DateTime.convert('15 15 15 07 01 2019',
@@ -246,6 +257,24 @@ class TestHarmonization(unittest.TestCase):
                          harmonization.DateTime.convert(129410017915727600,
                                                         'windows_nt'))
 
+    def test_datetime_parse_utc_isoformat(self):
+        """ Test DateTime.parse_utc_isoformat """
+        self.assertEqual('2020-12-31T12:00:00+00:00',
+                         harmonization.DateTime.parse_utc_isoformat('2020-12-31T12:00:00+00:00'))
+        self.assertEqual('2020-12-31T12:00:00.001+00:00',
+                         harmonization.DateTime.parse_utc_isoformat('2020-12-31T12:00:00.001+00:00'))
+        self.assertEqual(datetime.datetime(year=2020, month=12, day=31, hour=12, tzinfo=pytz.utc),
+                         harmonization.DateTime.parse_utc_isoformat('2020-12-31T12:00:00+00:00',
+                                                                    return_datetime=True))
+
+    def test_datetime_convert_fuzzy(self):
+        """ Test DateTime.convert_fuzzy """
+        self.assertEqual('2020-12-31T12:00:00+00:00',
+                         harmonization.DateTime.convert_fuzzy('2020-12-31T12:00:00+00:00'))
+        self.assertEqual('2020-12-31T12:00:00+00:00',
+                         harmonization.DateTime.convert_fuzzy('31st December 2020 12:00'))
+
+
     def test_fqdn_valid(self):
         """ Test FQDN.is_valid with valid arguments. """
         self.assertTrue(harmonization.FQDN.is_valid('ex-am.ple.example'))
