@@ -425,6 +425,44 @@ V222_OUT = {
     "parameters": {
         "feedname": "Blocklist"}}}
 
+V230_IN = {
+"urlhaus-parser": {
+    "module": "intelmq.bots.parsers.generic.parser_csv",
+    "parameters": {
+        "delimeter": ","
+    }
+}
+}
+V230_IN_BOTH = {
+"urlhaus-parser": {
+    "module": "intelmq.bots.parsers.generic.parser_csv",
+    "parameters": {
+        "delimeter": ",",
+        "delimiter": ","
+    }
+}
+}
+V230_OUT = {
+"urlhaus-parser": {
+    "module": "intelmq.bots.parsers.generic.parser_csv",
+    "parameters": {
+        "delimiter": ","
+    }
+}
+}
+V230_MALWAREDOMAINLIST_IN = {
+"malwaredomainlist-parser": {
+    "module": "intelmq.bots.parsers.malwaredomainlist.parser",
+    "parameters": {
+    }
+},
+"malwaredomainlist-collector": {
+    "module": "intelmq.bots.collectors.http.collector_http",
+    "parameters": {
+        "http_url": "http://www.malwaredomainlist.com/updatescsv.php"
+        }
+    }
+}
 
 def generate_function(function):
     def test_function(self):
@@ -573,6 +611,40 @@ class TestUpgradeLib(unittest.TestCase):
         self.assertTrue(result[0])
         self.assertEqual(V222_OUT, result[2])
 
+    def test_v230_csv_parser_parameter_fix(self):
+        """ Test v230_feed_fix """
+        result = upgrades.v230_csv_parser_parameter_fix({}, V230_IN, {}, False)
+        self.assertTrue(result[0])
+        self.assertEqual(V230_OUT, result[2])
+
+        # with also the new fixed parameter
+        result = upgrades.v230_csv_parser_parameter_fix({}, V230_IN_BOTH, {}, False)
+        self.assertTrue(result[0])
+        self.assertEqual(V230_OUT, result[2])
+
+        # with new parameter, no change
+        result = upgrades.v230_csv_parser_parameter_fix({}, V230_OUT, {}, False)
+        self.assertIsNone(result[0])
+        self.assertEqual(V230_OUT, result[2])
+
+    def test_v230_deprecations(self):
+        """ Test v230_deprecations """
+        result = upgrades.v230_deprecations({}, V230_MALWAREDOMAINLIST_IN, {}, False)
+        self.assertTrue(result[0])
+        self.assertEqual('A discontinued bot "Malware Domain List Parser" has been found as bot '
+                         'malwaredomainlist-parser. Remove affected bots yourself.',
+                         result[0])
+        self.assertEqual(V230_MALWAREDOMAINLIST_IN, result[2])
+
+    def test_v230_feed_changes(self):
+        """ Test v230_feed_changes """
+        result = upgrades.v230_feed_changes({}, V230_MALWAREDOMAINLIST_IN, {}, False)
+        self.assertTrue(result[0])
+        self.assertEqual('A discontinued feed "Malware Domain List" has been found as bot '
+                         'malwaredomainlist-collector. Remove affected bots yourself.',
+                         result[0])
+        self.assertEqual(V230_MALWAREDOMAINLIST_IN, result[2])
+
 
 for name in upgrades.__all__:
     setattr(TestUpgradeLib, 'test_function_%s' % name,
